@@ -279,7 +279,7 @@ int ext2_mount(long cons_dev, long p_offset, long quiet)
 	else
 		group_size = sizeof(struct ext2_group_desc);
 
-	printf("filesystem group size %d\n", group_size);
+	if (Debug) printf("filesystem group size %d\n", group_size);
 
 	gds = (struct ext2_group_desc *)malloc(ngroups * group_size);
 
